from django.apps import AppConfig


class DeliveryConfig(AppConfig):
    name = "delivery"
